@@ -38,7 +38,18 @@ class DBMonitorProvider(object):
         except Exception, e:
             LOG.error(str(e))
             raise e
-
+    
+    @classmethod
+    def get_sgbd(self, databaseinfra):
+        driver_name = databaseinfra.engine.engine_type.name.lower()
+        if re.match(r'^mongo.*', driver_name):
+            return SGBD_MONGODB
+        elif re.match(r'^mysql.*', driver_name):
+            return SGBD_MYSQL
+        else:
+            LOG.error('Not implemented engine type')
+            raise NotImplementedError()
+    
     @classmethod
     @transaction.commit_on_success
     def create_dbmonitor_monitoring(self, databaseinfra):
@@ -54,14 +65,7 @@ class DBMonitorProvider(object):
             flag_cluster_str = 'true'
             flag_cluster = True
             machine = ''
-        driver_name = databaseinfra.engine.engine_type.name.lower()
-        if re.match(r'^mongo.*', driver_name):
-            sgbd = SGBD_MONGODB
-        elif re.match(r'^mysql.*', driver_name):
-            sgbd = SGBD_MYSQL
-        else:
-            LOG.error('Not implemented engine type')
-            raise NotImplementedError()
+        sgbd = self.get_sgbd(databaseinfra)
         dns, port = databaseinfra.endpoint_dns.split(':')
         self.auth(environment)
         
@@ -94,7 +98,7 @@ class DBMonitorProvider(object):
         'coleta_info_sessoes': 'true',
         'coleta_info_tablespaces': 'false',
         'coleta_info_segmentos': 'false',
-        'coleta_info_backup': 'false',
+        'coleta_info_backup': 'true',
         'coleta_info_key_buffer': 'false',
         'testa_conexao': 'true',
         'coleta_tamanho_database': 'true',
@@ -149,8 +153,64 @@ class DBMonitorProvider(object):
             self.client.commit()
             
             infraattr.delete()
-            LOG.info('Monitoring in DBMonitor successfully removed')
             
         except Exception, e:
             LOG.error(str(e))
             raise e
+        
+        LOG.info('Monitoring in DBMonitor successfully removed')
+
+    @classmethod
+    @transaction.commit_on_success
+    def register_backup(self, databaseinfra, start_at, end_at, size, status, type):
+        
+        from backup.models import BackupInfo
+        
+        LOG.info('Registering backup on DBMonitor')
+        self.auth(databaseinfra.environment)
+        infraattr = DatabaseInfraAttr.objects.get(dbaas_databaseinfra=databaseinfra)
+        sgbd = self.get_sgbd(databaseinfra)
+        
+        if type == BackupInfo.SNAPSHOPT:
+            tipo_backup = 'snapshot'
+        else:
+            raise Exception("Unknown backup type")
+        
+        if status == BackupInfo.SUCCESS:
+            status_backup = 'COMPLETO'
+        else:                    
+            status_backup = 'FALHA'
+            
+        
+        backup_dict = {
+        'database_id': infraattr.dbmonitor_databaseinfra,
+        'data_inicio': start_at.strftime("%y-%m-%d %H:%M:%S"),
+        'data_fim': end_at.strftime("%y-%m-%d %H:%M:%S"),
+        'segundos_decorrido': int((end_at - start_at).total_seconds()),
+        'bytes_saida': size,
+        'status_backup': status_backup,
+        'tipo_backup': tipo_backup,
+        'info_adicional': '',
+        'compactado': 'false'
+        }
+        
+        if sgbd == SGBD_MYSQL:
+            sql = """INSERT INTO mysql_backup (database_id, data_inicio, data_fim, segundos_decorrido, bytes_saida, status_backup, tipo_backup)
+                     VALUES (%(database_id)s, '%(data_inicio)s', '%(data_fim)s', %(segundos_decorrido)s, %(bytes_saida)s, '%(status_backup)s', '%(tipo_backup)s')
+            """ % backup_dict
+        else:
+            sql = """INSERT INTO mongodb_backup (database_id, data_inicio, data_fim, segundos_decorrido, bytes_saida, status_backup, tipo_backup, info_adicional, compactado)
+                     VALUES (%(database_id)s, '%(data_inicio)s', '%(data_fim)s', %(segundos_decorrido)s, %(bytes_saida)s, '%(status_backup)s', '%(tipo_backup)s', '%(info_adicional)s', %(compactado)s)
+            """ % backup_dict
+        try:
+            
+            cursor = self.client.cursor()
+            cursor.execute(sql)
+            self.client.commit()
+        
+        except Exception, e:
+            LOG.error(str(e))
+            raise e
+        
+        LOG.info('Backup successfully registered on DBMonitor')
+        
\ No newline at end of file
